# OpenGPT (3.5/4)

![icon](https://media.discordapp.net/attachments/814722115831595018/1105152033603993810/20230508_121652.jpg)

OpenGPT 3.5/4 is a project aimed at providing practical and user-friendly APIs. The APIs allow for easy integration with various applications, making it simple for developers to incorporate the natural language processing capabilities of GPT into their projects. The user-friendly design of the APIs ensures that developers can quickly and easily start using the GPT technology, without having to navigate complex systems. OpenGPT 3.5/4 is the ideal solution for developers looking to enhance their applications with advanced natural language processing capabilities.

[<img src="https://assets-global.website-files.com/6257adef93867e50d84d30e2/636e0a6a49cf127bf92de1e2_icon_clyde_blurple_RGB.png" height="10" />&nbsp; Join our Community](https://discord.gg/W7tnxxA6mG)

[<img src="https://is1-ssl.mzstatic.com/image/thumb/Purple115/v4/2d/58/4a/2d584ac1-80c9-0ae5-5802-1db149f6a929/AppIcon-2x_U007euniversal-4-0-85-220.png/200x0w.webp" height="10" />&nbsp; Star this project](https://github.com/uesleibros/OpenGPT/stargazers)


## About the Project

This project was made so that everyone can have access to artificial intelligence models for free. Non-profit made by those who love to program!

### Services

- [<img src="https://seeklogo.com/images/O/open-ai-logo-8B9BFEDC26-seeklogo.com.png" height="15" /> Playground](https://gptplayground.uesleidev.repl.co/playground)

## Explaining some details

- We are currently organizing the project and as such, the source code for one of the AIs API has not been released yet.

- The artificial intelligence models used and APIs are not ours, it is being made clear so that it does not create confusion in the future.

- We are not responsible for what purposes you use these APIs. We just deliver so you can have fun with this new technology.

- Our purpose is not to harm any of these companies or leak content, we are just providing alternative uses so you can have fun.

## Artifical Intelligences

> remembering that all these models are from their respective companies, none of them are ours.

### Included

| Website | Model |
|---------|-------|
| [`chat.forefront.ai`](https://chat.forefront.ai/) | `GPT 3.5-Turbo`, `GPT-4` and **Internet** |
| [`ai.usesless.com`](https://ai.usesless.com/) | `GPT-3.5-Turbo`, `GPT-4` |
| [`italygpt.it`](https://italygpt.it/) | `GPT-3.5-Turbo` |
| [`chatgptproxy.me`](https://chatgptproxy.me/) | `GPT-3.5-Turbo` |
| [`chatllama.baseten.co`](https://chatllama.baseten.co/) | `Alpaca-7b` |
| [`chatbase.co`](https://chatbase.co/) | `GPT-3.5-Turbo`, `GPT-4` |

### Unfinished/Testing

| Website | Model |
|---------|-------|
| [`beta.character.ai`](https://beta.character.ai/) | `GANs` |

## Setup Project

### Installation

#### Source Code

Before starting to use OpenGPT, it is necessary to have the required dependencies to work. There are 2 ways to make the necessary installations:

- **Makefile**:
  - If you have `Make` installed on your machine, just run the following command: `make dependencies`. It will download all necessary dependencies.
  
- **Manual**:
  - If you don't have the Makefile installed on your machine, you can just type in your terminal the following: `pip install -r requirements.txt`. Which will also install all the necessary dependencies.
  
##### Project Architecture

First, you need to download the source code from this repository. After extracting the `.zip` file, you will have a folder called `OpenGPT`. You need to put it in your project, use example architecture:

```
my_project
├── OpenGPT
├── your_code
│   ├── ....
```

Now, for you to use it, just import: 
```py 
import OpenGPT 
```

#### Package

You can install this project as module using pip command.

```shell
pip install opengpt4
```

After install, for use it's simple, you can work with something model like this:

```py
from opengpt.forefront.model import Model

# .....
```

## Contribution

APIs play a crucial role in the development and implementation of AI systems. They provide a means of communication between different components of the AI system, as well as between the AI system and external applications. APIs can also facilitate the integration of AI systems into larger software systems.

At this stage, we welcome any contributions to our project, including pull requests.

By leveraging the power of APIs and collaborating with a diverse group of developers, we can push the boundaries of what is possible with AI technology. So if you're interested in contributing to our project, please don't hesitate to get in touch! [Contribute.](https://github.com/uesleibros/OpenGPT/pulls)
